#import "MSConvertCoordinatesViewController.h"

@interface MSConvertCoordinatesViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) UIView *markerView;
@property (nonatomic, strong) MRPointAnnotation *userAnnotation;
@end

@implementation MSConvertCoordinatesViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Position Markers" style:UIBarButtonItemStylePlain target:self action:@selector(layoutMarkers)];
        self.navigationItem.rightBarButtonItems = @[button1];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
    self.view = self.mapView;
    
    self.markerView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 10, 10)];
    self.markerView.backgroundColor = [UIColor redColor];
    [self.view addSubview:self.markerView];
    
    self.userAnnotation = [[MRPointAnnotation alloc] init];
    self.userAnnotation.point = CGPointMake(0, 0);
    [self.mapView addAnnotation:self.userAnnotation];
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Convert Coordinates";
}

+ (NSString *)exampleInfo {
    return @"Example of how to convert to and from the map coordinate system.\n\n"
    @"• Button to reposition red and blue markers.\n"
    @"• Blue annotation is moved to the center of the map view.\n"
    @"• Red view is moved above the 'KFC' placemark.\n";
}

#pragma mark - Action

- (void)layoutMarkers {
    MRPlacemark *placemark = nil;
    for (MRPlacemark *i in self.mapView.placemarks) {
        if ([i.title isEqual:@"KFC"]) {
            placemark = i;
        }
    }
    self.markerView.center = [self.mapView convertMapPoint:placemark.point toPointToView:self.view];
    [self.view bringSubviewToFront:self.markerView];
    
    self.userAnnotation.point = [self.mapView convertPoint:CGPointMake(CGRectGetMidX(self.view.bounds), CGRectGetMidY(self.view.bounds)) toMapPointFromView:self.view];
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    if (annotation == self.userAnnotation) {
        MRAnnotationView *annotationView = [self.mapView dequeueReusableAnnotationViewWithIdentifier:@"a"];
        if (!annotationView) {
            annotationView = [[MRAnnotationView alloc] initWithAnnotation:self.userAnnotation reuseIdentifier:@"a"];
            annotationView.frame = CGRectMake(0, 0, 10, 10);
            annotationView.backgroundColor = [UIColor blueColor];
        }
        return annotationView;
    }
    return nil;
}

- (void)mapPickerDidPickMap:(nonnull MRMap *)map {
    self.mapView.mapKey = map.key;
}

- (nonnull UIViewController *)viewControllerToAddSheetToForMapView:(MRMapView *)mapView {
    return self;
}

@end
