#import "MSCustomUserAnnotationViewController.h"

@interface MSUserAnnotationView : MRAnnotationView
@property (nonatomic, strong) CAShapeLayer *shapeLayer;
@end

@implementation MSUserAnnotationView
- (id)initWithAnnotation:(id<MRAnnotation>)annotation reuseIdentifier:(NSString *)reuseIdentifier {
    if ((self = [super initWithAnnotation:annotation reuseIdentifier:reuseIdentifier])) {
        self.shapeLayer = [CAShapeLayer layer];
        self.shapeLayer.path = [UIBezierPath bezierPathWithOvalInRect:CGRectMake(0, 0, 20, 20)].CGPath;
        self.shapeLayer.lineWidth = 3;
        self.shapeLayer.fillColor = [UIColor orangeColor].CGColor;
        self.shapeLayer.strokeColor = [UIColor whiteColor].CGColor;
        self.shapeLayer.shadowOpacity = 0.5;
        self.shapeLayer.shadowOffset = CGSizeMake(0, 1);
        [self.layer addSublayer:self.shapeLayer];
        
        self.frame = CGRectMake(0, 0, 20, 20);
    }
    return self;
}
@end

@interface MSCustomUserAnnotationViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@end

@implementation MSCustomUserAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
    self.mapView.showsUserLocation = YES;
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom User Annotation";
}

+ (NSString *)exampleInfo {
    return @"Example of how to customize annotations by returning a MRAnnotationView subclass.\n\n"
    @"• Custom orange user location annotation.\n";
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    if ([annotation isKindOfClass:[MRUserLocation class]]) {
        MSUserAnnotationView *view = (MSUserAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:@"MSUserAnnotationView"];
        if (!view) {
            view = [[MSUserAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"MSUserAnnotationView"];
        }
        return view;
    }
    return nil;
}

- (void)mapPickerDidPickMap:(nonnull MRMap *)map {
    self.mapView.mapKey = map.key;
}

- (nonnull UIViewController *)viewControllerToAddSheetToForMapView:(MRMapView *)mapView {
    return self;
}

@end
