#import "MSFriendViewController.h"
#import "MSFriendManager.h"
#import "MSFriendMapController.h"
#import "MSInviteViewController.h"
#import "MSProfileViewController.h"

@interface MSFriendViewController () <MSFriendManagerObserver>
@end

@implementation MSFriendViewController

- (id)init {
    if ((self = [super initWithStyle:UITableViewStyleGrouped])) {
        [self.manager addObserver:self];
        [self.manager reloadData];
        [MSFriendManager setActiveManager:self.manager];
    }
    return self;
}

- (void)dealloc {
    [self.manager removeObserver:self];
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Friend A";
}

+ (NSString *)exampleInfo {
    return @"Example of how to show friends on a map, as well as manage user profiles and friend lists.";
}

#pragma mark - UITableViewDataSource

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    if (section == 0) {
        if (self.manager) {
            return 6;
        } else {
            return 1;
        }
    } else if (section == 1) {
        return self.manager.friends.count;
    } else if (section == 2) {
        return self.manager.invites.count;
    }
    return 0;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:nil];
    if (indexPath.section == 0) {
        if (indexPath.row == 0) {
            cell.textLabel.text = @"New User";
            if (self.manager.profile) {
                [self setEnabled:NO forTableCell:cell];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"\"%@\"", self.manager.profile.name];
            } else {
                [self setEnabled:YES forTableCell:cell];
                cell.detailTextLabel.text = nil;
            }
        } else if (indexPath.row == 1) {
            cell.textLabel.text = @"Create Invite";
        } else if (indexPath.row == 2) {
            cell.textLabel.text = @"Accept Invite";
        } else if (indexPath.row == 3) {
            cell.textLabel.text = @"View Map";
        } else if (indexPath.row == 4) {
            cell.textLabel.text = @"View Profile";
        } else if (indexPath.row == 5) {
            cell.textLabel.text = @"Delete Profile";
        }
        
        if (indexPath.row > 0) {
            [self setEnabled:(self.manager.session != nil) forTableCell:cell];
        }
        
    } else if (indexPath.section == 1) {
        MRFriend *friend = self.manager.friends[indexPath.row];
        cell.textLabel.text = friend.name;
    } else if (indexPath.section == 2) {
        MRInvite *invite = self.manager.invites[indexPath.row];
        cell.textLabel.text = invite.key.identifier;
    }
    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    if (section == 0) {
        return @"Actions";
    } else if (section == 1) {
        return @"Friends";
    } else if (section == 2) {
        return @"Invites";
    }
    return nil;
}

#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    if (indexPath.section == 0) {
        if (indexPath.row == 0) {
            __weak typeof(self) weakSelf = self;
            UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"Create User" message:nil preferredStyle:UIAlertControllerStyleAlert];
            [alert addTextFieldWithConfigurationHandler:^(UITextField *field){field.placeholder = @"Name";}];
            [alert addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action){
                [weakSelf.manager newAccountWithPassword:[NSUUID UUID].UUIDString name:alert.textFields[0].text];
            }]];
            [self presentViewController:alert animated:YES completion:nil];
        } else if (indexPath.row == 1) {
            __weak typeof(self) weakSelf = self;
            [MRInvite createInviteWithSession:self.manager.session completion:^(MRInvite *invite, NSError *error){
                if (!error) {
                    [weakSelf.manager reloadData];
                } else {
                    [weakSelf handleFriendError:error];
                }
            }];
        } else if (indexPath.row == 2) {
            __weak typeof(self) weakSelf = self;
            UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"Accept Invite" message:nil preferredStyle:UIAlertControllerStyleAlert];
            [alert addTextFieldWithConfigurationHandler:^(UITextField *field){field.placeholder = @"Invite Key";}];
            [alert addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action){
                [MRInvite acceptInviteWithKey:[MREditorKey keyWithIdentifier:alert.textFields[0].text] session: self.manager.session completion: ^(MRFriend *friend, NSError *error){
                    if (!error) {
                        [weakSelf.manager reloadData];
                    } else {
                        [weakSelf handleFriendError:error];
                    }
                }];
            }]];
            [self presentViewController:alert animated:YES completion:nil];
        } else if (indexPath.row == 3) {
            MSFriendMapController *vc = [[MSFriendMapController alloc] initWithSession:self.manager.session];
            [self.navigationController pushViewController:vc animated:YES];
        } else if (indexPath.row == 4) {
            UIViewController *vc = [[MSProfileViewController alloc] initWithManager:self.manager];
            [self.navigationController pushViewController:vc animated:YES];
        } else if (indexPath.row == 5) {
            [self.manager deleteAccount];
        }
    } else if (indexPath.section == 1) {
        UIViewController *vc = [[MSProfileViewController alloc] initWithFriend:self.manager.friends[indexPath.row] manager:self.manager];
        [self.navigationController pushViewController:vc animated:YES];
    } else if (indexPath.section == 2) {
        MSInviteViewController *vc = [[MSInviteViewController alloc] initWithInvite:self.manager.invites[indexPath.row] manager:self.manager];
        [self.navigationController pushViewController:vc animated:YES];
    }
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath {
    return indexPath.section == 1 || indexPath.section == 2;
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    __weak typeof(self) weakSelf = self;
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        if (indexPath.section == 1) {
            [MRFriend removeFriendWithKey:((MRFriend *)self.manager.friends[indexPath.row]).key session:self.manager.session completion:^(NSError *error) {
                if (!error) {
                    [weakSelf.manager reloadData];
                }
            }];
            [tableView reloadData];
        } else if (indexPath.section == 2) {
            [(MRInvite *)self.manager.invites[indexPath.row] deleteWithSession:self.manager.session completion:^(NSError *error) {
                if (!error) {
                    [weakSelf.manager reloadData];
                }
            }];
            [tableView reloadData];
        }
    }
}

#pragma mark - MSFriendManagerObserver

- (void)friendManagerDidUpdate:(MSFriendManager *)manager {
    [self.tableView reloadData];
}

- (void)friendManagerDidFailWithError:(NSError *)error {
    [self handleFriendError:error];
}

#pragma mark - Internal

- (MSFriendManager *)manager {
    return [MSFriendManager manager1];
}

- (void)setEnabled:(BOOL)enabled forTableCell:(UITableViewCell *)cell {
    cell.textLabel.enabled = enabled;
    cell.userInteractionEnabled = enabled;
    cell.selectionStyle = enabled? UITableViewCellSelectionStyleDefault : UITableViewCellSelectionStyleNone;
}

@end

@implementation MSFriendViewController2

+ (NSString *)exampleTitle {
    return @"Friend B";
}

- (MSFriendManager *)manager {
    return [MSFriendManager manager2];
}

@end

@implementation MSFriendViewController3

+ (NSString *)exampleTitle {
    return @"Friend C";
}

- (MSFriendManager *)manager {
    return [MSFriendManager manager3];
}

@end
