#import "MSSelectAnnotationViewController.h"

@interface MSSelectAnnotationViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic) BOOL selectedOnLoad;
@end

@implementation MSSelectAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Select" style:UIBarButtonItemStylePlain target:self action:@selector(selectAnnotation)];
        UIBarButtonItem *button2 = [[UIBarButtonItem alloc] initWithTitle:@"Deselect" style:UIBarButtonItemStylePlain target:self action:@selector(deselectAnnotation)];
        self.navigationItem.rightBarButtonItems = @[button1, button2];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Select Annotation";
}

+ (NSString *)exampleInfo {
    return @"Example of how to programatically select annotations.\n\n"
    @"• `Converse` annotation starts initially selected.\n"
    @"• Button to select/deselect the `Gant` annotation.\n";
}

#pragma mark - MRMapViewDelegate

- (void)mapView:(MRMapView *)mapView didAddAnnotationViews:(NSArray *)views {
    if (!self.selectedOnLoad) {
        for (MRAnnotationView *view in views) {
            if ([view.annotation.title isEqualToString:@"Converse"]) {
                [mapView selectAnnotation:view.annotation animated:YES];
                self.selectedOnLoad = YES;
            }
        }
    }
}

- (void)mapPickerDidPickMap:(nonnull MRMap *)map {
    self.mapView.mapKey = map.key;
}

- (nonnull UIViewController *)viewControllerToAddSheetToForMapView:(MRMapView *)mapView {
    return self;
}

#pragma mark - Action

- (void)selectAnnotation {
    for (id<MRAnnotation> i in self.mapView.placemarks) {
        if ([i.title isEqual:@"Gant"]) {
            [self.mapView selectAnnotation:i animated:YES];
        }
    }
}

- (void)deselectAnnotation {
    [self.mapView deselectAnnotationAnimated:YES];
}

@end
