//
//  MSConvertCoordinatesViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/18/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSConvertCoordinatesViewController: UIViewController, MSExampleViewController, MRMapViewDelegate {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MSExampleHost.mapID(), app:MSExampleHost.appID())
        return mapView
    }()

    private lazy var markerView: UIView = {
        let markerView = UIView(frame: CGRect(x:0, y:0, width:10, height:10))
        markerView.backgroundColor = UIColor.red
        return markerView
    }()

    private lazy var userAnnotation: MRPointAnnotation = {
        let userAnnotation = MRPointAnnotation()
        userAnnotation.point = CGPoint(x:0, y:0)
        return userAnnotation
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.mapView.addAnnotation(self.userAnnotation)
        self.mapView.addSubview(self.markerView)
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Position Markers", style: .plain, target: self, action: #selector(self.layoutMarkers))
        self.navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Convert Coordinates"
    }

    static func exampleDetail() -> String {
        return "Example of how to convert to and from the map coordinate system.\n\n" +
            "• Button to reposition red and blue markers.\n" +
            "• Blue annotation is moved to the center of the map view.\n" +
            "• Red view is moved above the 'KFC' placemark.\n"
    }

    // MARK: - Action

    @objc private func layoutMarkers() {
        for case let placemark as MRPlacemark in self.mapView.placemarks {
            if let title = placemark.title, title == "KFC" {
                self.markerView.center = self.mapView.convertMapPoint(placemark.point, toPointTo: self.view)
                self.view.bringSubview(toFront: self.markerView)
                self.userAnnotation.point = self.mapView.convert(CGPoint(x: self.view.bounds.midX, y: self.view.bounds.midY), toMapPointFrom: self.view)
                break
            }
        }
    }

    // MARK: - MRMapViewDelegate
        
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }

    func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        if let thisAnnotation = annotation as? MRPointAnnotation, thisAnnotation == self.userAnnotation {
            if let annotationView = self.mapView.dequeueReusableAnnotationView(withIdentifier: "a") {
                return annotationView
            }
            let annotationView = MRAnnotationView.init(annotation: userAnnotation, reuseIdentifier: "a")
            annotationView.frame = CGRect(x: 0, y: 0, width: 10, height: 10)
            annotationView.backgroundColor = UIColor.blue
            return annotationView
        }
        return nil
    }
}
