//
//  MSCustomAnnotationSubclassViewController.swift
//  MeridianSwiftSamples
//
//  Created by Daniel Miedema on 5/16/18.
//  Copyright © 2018 Aruba Networks. All rights reserved.
//

import UIKit
import Meridian

class MSCustomAnnotationSubclassViewController: MRMapViewController {
    lazy var key: MREditorKey = {
        return MREditorKey(forMap:MSExampleHost.mapID(), app:MSExampleHost.appID())
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        mapView.mapKey = key
    }

    // MARK: - MRMapViewDelegate overrides
    override func mapViewDidFinishLoadingMap(_ mapView: MRMapView) {
        let x = mapView.map.size.width  / 2.0
        let y = mapView.map.size.height / 2.0
        let annotation = CustomAnnotation(map: key, point: CGPoint(x: x, y: y))

        mapView.addAnnotation(annotation)
    }

    override func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        if let annotation = annotation as? CustomAnnotation {
            return CustomAnnotationView(annotation: annotation, reuseIdentifier: "best identifier")
        }
        return nil
    }
}

// MARK: - MSExampleViewController
extension MSCustomAnnotationSubclassViewController: MSExampleViewController {
    static func exampleTitle() -> String {
        return "Custom Annotation Subclass Example"
    }

    static func exampleDetail() -> String {
        return "Example of how to use create a custom MRAnnotationView Subclass.\n\n" +
            "See `MSCustomMapAnnotation.swift` for the code example and more detailed information/documentation."
    }
}
