//
//  MSCustomCalloutViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSCustomCalloutViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MSExampleHost.mapID(), app:MSExampleHost.appID())
        return mapView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Custom Callouts"
    }

    static func exampleDetail() -> String {
        return "Example of how to customize annotation callouts.\n\n" +
            "• All annotations have a smiley image as their callout view.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }
    
    func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        guard let thisAnnotation = annotation else {
            return nil
        }
        let smileyView = UIImageView(image: #imageLiteral(resourceName: "Smiley"))
        let annotationView = mapView.defaultView(for: thisAnnotation)
        annotationView.calloutContentView = smileyView
        annotationView.calloutContentMargin = 20.0
        return annotationView
    }
}
