//
//  MSCustomUserAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSUserAnnotationView: MRAnnotationView {
    private lazy var shapeLayer: CAShapeLayer = {
        let shapeLayer = CAShapeLayer()
        shapeLayer.path = UIBezierPath.init(ovalIn: CGRect(x: 0, y: 0, width: 20, height: 20)).cgPath
        shapeLayer.lineWidth = 3
        shapeLayer.fillColor = UIColor.orange.cgColor
        shapeLayer.strokeColor = UIColor.white.cgColor
        shapeLayer.shadowOpacity = 0.5
        shapeLayer.shadowOffset = CGSize(width: 0, height: 1)
        return shapeLayer
    }()

    override init(annotation: MRAnnotation, reuseIdentifier: String) {
        super.init(annotation: annotation, reuseIdentifier: reuseIdentifier)
        initializeShapeLayer()
    }

    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        initializeShapeLayer()
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        initializeShapeLayer()
    }

    func initializeShapeLayer() {
        self.layer.addSublayer(self.shapeLayer)
        self.frame = CGRect(x: 0, y: 0, width: 20, height: 20)
    }
}

class MSCustomUserAnnotationViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.showsUserLocation = true
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MSExampleHost.mapID(), app:MSExampleHost.appID())
        return mapView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Custom User Annotation"
    }

    static func exampleDetail() -> String {
        return "Example of how to customize annotations by returning a MRAnnotationView subclass.\n\n" +
            "• Custom orange user location annotation.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }
    
    func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        guard let placemark = annotation as? MRUserLocation else {
            return nil
        }
        if let view = mapView.dequeueReusableAnnotationView(withIdentifier: "MSUserAnnotationView") {
            return view
        }
        return MSUserAnnotationView.init(annotation: placemark, reuseIdentifier: "MSUserAnnotationView")
    }
}
