//
//  MSShowsButtonsViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSShowsButtonsViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.showsUserLocation = true
        mapView.mapKey = MREditorKey(forMap:MSExampleHost.mapID(), app:MSExampleHost.appID())
        return mapView
    }()
    var directions: MRDirections?

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Map", style: .plain, target: self, action: #selector(self.toggleLevels))
        let button1 = UIBarButtonItem(title: "Over.", style: .plain, target: self, action: #selector(self.toggleOverview))
        let button2 = UIBarButtonItem(title: "Loc.", style: .plain, target: self, action: #selector(self.toggleLocation))
        let button3 = UIBarButtonItem(title: "Acc.", style: .plain, target: self, action: #selector(self.toggleAccessibility))
        let button4 = UIBarButtonItem(title: "Dir.", style: .plain, target: self, action: #selector(self.toggleDirections))
        self.navigationItem.rightBarButtonItems = [button0, button1, button2, button3, button4]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Button Visibility"
    }

    static func exampleDetail() -> String {
        return "Example of how to show/hide map buttons.\n\n" +
            "• `Dir.` button to start and stop directions.\n" +
            "• `Acc.` button to toggle accessibility button visibility.\n" +
            "• `Loc.` button to toggle location button visibility.\n" +
            "• `Over.` button to toggle overview button visibility.\n" +
            "• `Map` button to toggle map picker visibility.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }
    
    func directionsResponseDidLoad(response: MRDirectionsResponse?, error: Error?) {
        self.directions = nil
        if let routeResponse = response?.routes, error == nil, routeResponse.count > 0 {
            self.mapView.setRoute(routeResponse[0], animated: true)
            return
        }

        // Error or no routes:
        let alertController = UIAlertController(title: "Could not load directions", message: error?.localizedDescription, preferredStyle: .alert)
        let OKAction = UIAlertAction(title: "OK", style: .default)
        alertController.addAction(OKAction)
        self.present(alertController, animated: true)
    }

    // MARK: - Action

    @objc private func toggleDirections() {
        if self.mapView.route == nil && self.mapView.placemarks.count > 1 {
            guard let appKey = self.mapView.mapKey.parent else {
                return
            }
            guard let destinationPlacemark = self.mapView.placemarks[0] as? MRPlacemark else {
                return
            }
            guard let sourcePlacemark = self.mapView.placemarks[1] as? MRPlacemark else {
                return
            }
            let request = MRDirectionsRequest()
            request.app = appKey
            request.destination = MRDirectionsDestination(placemarkKey: destinationPlacemark.key)
            request.source = MRDirectionsSource(placemarkKey: sourcePlacemark.key)

            self.directions = MRDirections(request: request, presenting: self)
            self.directions?.calculate(completionHandler: { [weak self] (response, error) in
                self?.directionsResponseDidLoad(response: response, error: error)
            })
        } else {
            self.mapView.route = nil
        }
    }

    @objc private func toggleLevels() {
        self.mapView.showsMapPicker = !self.mapView.showsMapPicker
    }

    @objc private func toggleOverview() {
        self.mapView.showsOverviewButton = !self.mapView.showsOverviewButton
    }

    @objc private func toggleLocation() {
        self.mapView.showsLocationButton = !self.mapView.showsLocationButton
    }

    @objc private func toggleAccessibility() {
        self.mapView.showsAccessibilityButton = !self.mapView.showsAccessibilityButton
    }
}
